@@ -32,7 +32,7 @@ import org.apache.spark.broadcast.Broadcast
 import org.apache.spark.internal.Logging
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.catalog.CatalogTablePartition
-import org.apache.spark.sql.connector.read.{InputPartition, PartitionReader}
+import org.apache.spark.sql.connector.read.{InputPartition, PartitionReader, PartitionReaderFactory}
 import org.apache.spark.sql.execution.datasources.{FilePartition, PartitionedFile}
 import org.apache.spark.sql.execution.datasources.v2._
 import org.apache.spark.sql.hive.kyuubi.connector.HiveBridgeHelper.{HiveClientImpl, NextIterator}
@@ -41,6 +41,8 @@ import org.apache.spark.sql.sources.Filter
 import org.apache.spark.sql.types._
 import org.apache.spark.util.SerializableConfiguration
 
+import org.apache.kyuubi.spark.connector.hive.HiveConnectorUtils
+
 case class HivePartitionReaderFactory(
     sqlConf: SQLConf,
     broadcastHiveConf: Broadcast[SerializableConfiguration],
@@ -50,7 +52,7 @@ case class HivePartitionReaderFactory(
     partitionSchema: StructType,
     partFileToHivePart: Map[PartitionedFile, CatalogTablePartition],
     pushedFilters: Array[Filter] = Array.empty)
-  extends FilePartitionReaderFactory with Logging {
+  extends PartitionReaderFactory with Logging {
 
   private val charset: String =
     sqlConf.getConfString("hive.exec.default.charset", "utf-8")
@@ -58,10 +60,6 @@ case class HivePartitionReaderFactory(
   val tableDesc = HiveReader.getTableDec(hiveTable)
   val nonPartitionReadDataKeys = HiveReader.toAttributes(readDataSchema)
 
-  override def buildReader(partitionedFile: PartitionedFile): PartitionReader[InternalRow] = {
-    throw new UnsupportedOperationException("Cannot use buildReader directly.")
-  }
-
   override def createReader(partition: InputPartition): PartitionReader[InternalRow] = {
     assert(partition.isInstanceOf[FilePartition])
     val filePartition = partition.asInstanceOf[FilePartition]
@@ -84,7 +82,7 @@ case class HivePartitionReaderFactory(
             partitionSchema,
             file.partitionValues))
       }
-    new FilePartitionReader[InternalRow](iter)
+    new SparkFilePartitionReader[InternalRow](iter)
   }
 
   private def buildReaderInternal(
@@ -114,7 +112,7 @@ case class HivePartitionReaderFactory(
 
     val jobConf = new JobConf(broadcastHiveConf.value.value)
 
-    val filePath = new Path(new URI(file.filePath))
+    val filePath = new Path(new URI(HiveConnectorUtils.partitionedFilePath(file)))
 
     if (tableDesc != null) {
       configureJobPropertiesForStorageHandler(tableDesc, jobConf, true)
