@@ -21,6 +21,7 @@ import static org.apache.kyuubi.jdbc.hive.JdbcConnectionParams.*;
 
 import com.google.common.annotations.VisibleForTesting;
 import java.io.*;
+import java.nio.file.Files;
 import java.sql.*;
 import java.util.*;
 import org.apache.hive.beeline.logs.KyuubiBeelineInPlaceUpdateStream;
@@ -86,10 +87,9 @@ public class KyuubiCommands extends Commands {
   }
 
   private boolean sourceFileInternal(File sourceFile) throws IOException {
-    BufferedReader reader = null;
-    try {
-      reader = new BufferedReader(new FileReader(sourceFile));
-      String lines = null, extra;
+    try (BufferedReader reader = Files.newBufferedReader(sourceFile.toPath())) {
+      String lines = null;
+      String extra;
       while ((extra = reader.readLine()) != null) {
         if (beeLine.isComment(extra)) {
           continue;
@@ -107,10 +107,6 @@ public class KyuubiCommands extends Commands {
           return false;
         }
       }
-    } finally {
-      if (reader != null) {
-        reader.close();
-      }
     }
     return true;
   }
@@ -362,7 +358,7 @@ public class KyuubiCommands extends Commands {
    */
   private void addCmdPart(List<String> cmdList, StringBuilder command, String cmdpart) {
     if (cmdpart.endsWith("\\")) {
-      command.append(cmdpart.substring(0, cmdpart.length() - 1)).append(";");
+      command.append(cmdpart, 0, cmdpart.length() - 1).append(";");
       return;
     } else {
       command.append(cmdpart);
@@ -427,6 +423,7 @@ public class KyuubiCommands extends Commands {
     return null;
   }
 
+  @Override
   public boolean connect(Properties props) throws IOException {
     String url =
         getProperty(
@@ -521,7 +518,6 @@ public class KyuubiCommands extends Commands {
 
   @Override
   public String handleMultiLineCmd(String line) throws IOException {
-    int[] startQuote = {-1};
     Character mask =
         (System.getProperty("jline.terminal", "").equals("jline.UnsupportedTerminal"))
             ? null
