@@ -35,9 +35,10 @@ import org.apache.kyuubi.server.api.v1.ApiRootResource
 import org.apache.kyuubi.server.http.authentication.{AuthenticationFilter, KyuubiHttpAuthenticationFactory}
 import org.apache.kyuubi.server.ui.{JettyServer, JettyUtils}
 import org.apache.kyuubi.service.{AbstractFrontendService, Serverable, Service, ServiceUtils}
-import org.apache.kyuubi.service.authentication.{AuthMethods, AuthTypes, KyuubiAuthenticationFactory}
+import org.apache.kyuubi.service.authentication.{AuthTypes, AuthUtils}
 import org.apache.kyuubi.session.{KyuubiSessionManager, SessionHandle}
 import org.apache.kyuubi.util.ThreadUtils
+import org.apache.kyuubi.util.ThreadUtils.scheduleTolerableRunnableWithFixedDelay
 
 /**
  * A frontend service based on RESTful api via HTTP protocol.
@@ -70,9 +71,10 @@ class KyuubiRestFrontendService(override val serverable: Serverable)
 
   private lazy val port: Int = conf.get(FRONTEND_REST_BIND_PORT)
 
-  private lazy val securityEnabled = {
+  private[kyuubi] lazy val securityEnabled = {
     val authTypes = conf.get(AUTHENTICATION_METHOD).map(AuthTypes.withName)
-    KyuubiAuthenticationFactory.getValidPasswordAuthMethod(authTypes) != AuthMethods.NONE
+    AuthUtils.kerberosEnabled(authTypes) ||
+    !AuthUtils.effectivePlainAuthType(authTypes).contains(AuthTypes.NONE)
   }
 
   private lazy val administrators: Set[String] =
@@ -87,7 +89,8 @@ class KyuubiRestFrontendService(override val serverable: Serverable)
       getName,
       host,
       port,
-      conf.get(FRONTEND_REST_MAX_WORKER_THREADS))
+      conf.get(FRONTEND_REST_MAX_WORKER_THREADS),
+      conf.get(FRONTEND_REST_JETTY_STOP_TIMEOUT))
     super.initialize(conf)
   }
 
@@ -142,7 +145,12 @@ class KyuubiRestFrontendService(override val serverable: Serverable)
       }
     }
 
-    batchChecker.scheduleWithFixedDelay(task, interval, interval, TimeUnit.MILLISECONDS)
+    scheduleTolerableRunnableWithFixedDelay(
+      batchChecker,
+      task,
+      interval,
+      interval,
+      TimeUnit.MILLISECONDS)
   }
 
   @VisibleForTesting
@@ -221,7 +229,7 @@ class KyuubiRestFrontendService(override val serverable: Serverable)
 
   def getSessionUser(hs2ProxyUser: String): String = {
     val sessionConf = Option(hs2ProxyUser).filter(_.nonEmpty).map(proxyUser =>
-      Map(KyuubiAuthenticationFactory.HS2_PROXY_USER -> proxyUser)).getOrElse(Map())
+      Map(AuthUtils.HS2_PROXY_USER -> proxyUser)).getOrElse(Map())
     getSessionUser(sessionConf)
   }
 
@@ -250,9 +258,9 @@ class KyuubiRestFrontendService(override val serverable: Serverable)
     if (sessionConf == null) {
       realUser
     } else {
-      sessionConf.get(KyuubiAuthenticationFactory.HS2_PROXY_USER).map { proxyUser =>
+      sessionConf.get(AuthUtils.HS2_PROXY_USER).map { proxyUser =>
         if (!isAdministrator(realUser)) {
-          KyuubiAuthenticationFactory.verifyProxyAccess(realUser, proxyUser, ipAddress, hadoopConf)
+          AuthUtils.verifyProxyAccess(realUser, proxyUser, ipAddress, hadoopConf)
         }
         proxyUser
       }.getOrElse(realUser)
