@@ -32,6 +32,7 @@ import org.apache.kyuubi.server.metadata.api.{Metadata, MetadataFilter}
 import org.apache.kyuubi.service.AbstractService
 import org.apache.kyuubi.session.SessionType
 import org.apache.kyuubi.util.{ClassUtils, JdbcUtils, ThreadUtils}
+import org.apache.kyuubi.util.ThreadUtils.scheduleTolerableRunnableWithFixedDelay
 
 class MetadataManager extends AbstractService("MetadataManager") {
   import MetadataManager._
@@ -209,7 +210,8 @@ class MetadataManager extends AbstractService("MetadataManager") {
       }
     }
 
-    metadataCleaner.scheduleWithFixedDelay(
+    scheduleTolerableRunnableWithFixedDelay(
+      metadataCleaner,
       cleanerTask,
       interval,
       interval,
@@ -298,7 +300,9 @@ class MetadataManager extends AbstractService("MetadataManager") {
         }
       }
     }
-    requestsAsyncRetryTrigger.scheduleWithFixedDelay(
+
+    scheduleTolerableRunnableWithFixedDelay(
+      requestsAsyncRetryTrigger,
       triggerTask,
       requestsRetryInterval,
       requestsRetryInterval,
