@@ -36,9 +36,9 @@ abstract class KyuubiSession(
 
   val sessionType: SessionType
 
-  val connectionUrl = conf.get(KYUUBI_SESSION_CONNECTION_URL_KEY).getOrElse("")
+  val connectionUrl = conf.getOrElse(KYUUBI_SESSION_CONNECTION_URL_KEY, "")
 
-  val realUser = conf.get(KYUUBI_SESSION_REAL_USER_KEY).getOrElse(user)
+  val realUser = conf.getOrElse(KYUUBI_SESSION_REAL_USER_KEY, user)
 
   def getSessionEvent: Option[KyuubiSessionEvent]
 
@@ -61,11 +61,13 @@ abstract class KyuubiSession(
     ms.incCount(CONN_TOTAL)
     ms.incCount(MetricRegistry.name(CONN_TOTAL, sessionType.toString))
     ms.incCount(MetricRegistry.name(CONN_OPEN, user))
+    ms.incCount(MetricRegistry.name(CONN_OPEN, user, sessionType.toString))
     ms.incCount(MetricRegistry.name(CONN_OPEN, sessionType.toString))
   }
 
   protected def traceMetricsOnClose(): Unit = MetricsSystem.tracing { ms =>
     ms.decCount(MetricRegistry.name(CONN_OPEN, user))
+    ms.decCount(MetricRegistry.name(CONN_OPEN, user, sessionType.toString))
     ms.decCount(MetricRegistry.name(CONN_OPEN, sessionType.toString))
   }
 }
